@@ -12,7 +12,7 @@ package Kernel::Modules::AdminAutoResponse;
 use strict;
 use warnings;
 
-use Kernel::Language              qw(Translatable);
+use Kernel::Language qw(Translatable);
 use Kernel::System::VariableCheck qw(:all);
 
 our $ObjectManagerDisabled = 1;
@@ -226,21 +226,18 @@ sub Run {
         # challenge token check for write action
         $LayoutObject->ChallengeTokenCheck();
 
-        my $ID = $ParamObject->GetParam( Param => 'ID' );
+        my %GetParam;
+        for my $Parameter (qw(ID)) {
+            $GetParam{$Parameter} = $ParamObject->GetParam( Param => $Parameter ) || '';
+        }
 
         my $Delete = $AutoResponseObject->AutoResponseDelete(
-            ID     => $ID,
+            ID     => $GetParam{ID},
             UserID => $Self->{UserID},
         );
 
         return $LayoutObject->ErrorScreen() if !$Delete;
-
-        return $LayoutObject->Attachment(
-            ContentType => 'text/html',
-            Content     => $Delete,
-            Type        => 'inline',
-            NoCache     => 1,
-        );
+        return $LayoutObject->Redirect( OP => "Action=$Self->{Action}" );
     }
 
     # ------------------------------------------------------------ #
@@ -547,19 +544,6 @@ sub _Overview {
                     Attachments => int rand 5,
                 },
             );
-
-            my %AutoResponseQueues = $AutoResponseObject->AutoResponseQueuesList(
-                ID => $ID,
-            );
-
-            if ( !%AutoResponseQueues ) {
-                $LayoutObject->Block(
-                    Name => 'DeleteLink',
-                    Data => {
-                        ID => $ID,
-                    },
-                );
-            }
         }
     }
 
