@@ -15,7 +15,7 @@ use utf8;
 
 use Mail::Address;
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language              qw(Translatable);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -165,13 +165,6 @@ sub Run {
                         TicketID => $Self->{TicketID}
                     },
                 );
-                $LayoutObject->Block(
-                    Name => 'PropertiesLockNotify',
-                    Data => {
-                        %Param,
-                        TicketID => $Self->{TicketID}
-                    },
-                );
             }
         }
         else {
@@ -367,7 +360,7 @@ sub Run {
                 DynamicFieldConfig   => $DynamicFieldConfig,
                 PossibleValuesFilter => $PossibleValuesFilter,
                 Value                => $Value,
-                Mandatory            =>
+                Mandatory =>
                     $Config->{DynamicField}->{ $DynamicFieldConfig->{Name} } == 2,
                 LayoutObject    => $LayoutObject,
                 ParamObject     => $ParamObject,
@@ -400,7 +393,6 @@ sub Run {
             SLAID        => $Ticket{SLAID},
             TicketNumber => $Ticket{TicketNumber},
             Title        => $Ticket{Title},
-            State        => $Ticket{State},
             NextStates   => $Self->_GetNextStates(
                 %GetParam,
             ),
@@ -702,7 +694,7 @@ sub Run {
                 DynamicFieldConfig   => $DynamicFieldConfig,
                 PossibleValuesFilter => $PossibleValuesFilter,
                 ParamObject          => $ParamObject,
-                Mandatory            =>
+                Mandatory =>
                     $Config->{DynamicField}->{ $DynamicFieldConfig->{Name} } == 2,
             );
 
@@ -725,13 +717,13 @@ sub Run {
                 $DynamicFieldBackendObject->EditFieldRender(
                 DynamicFieldConfig   => $DynamicFieldConfig,
                 PossibleValuesFilter => $PossibleValuesFilter,
-                Mandatory            =>
+                Mandatory =>
                     $Config->{DynamicField}->{ $DynamicFieldConfig->{Name} } == 2,
-                ServerError     => $ValidationResult->{ServerError}  || '',
-                ErrorMessage    => $ValidationResult->{ErrorMessage} || '',
-                LayoutObject    => $LayoutObject,
-                ParamObject     => $ParamObject,
-                AJAXUpdate      => 1,
+                ServerError  => $ValidationResult->{ServerError}  || '',
+                ErrorMessage => $ValidationResult->{ErrorMessage} || '',
+                LayoutObject => $LayoutObject,
+                ParamObject  => $ParamObject,
+                AJAXUpdate   => 1,
                 UpdatableFields => $Self->_GetFieldsToUpdate(),
                 );
         }
@@ -788,7 +780,6 @@ sub Run {
                 QueueID      => $Ticket{QueueID},
                 SLAID        => $Ticket{SLAID},
                 Title        => $Ticket{Title},
-                State        => $Ticket{State},
                 NextStates   => $Self->_GetNextStates(
                     %GetParam,
                 ),
@@ -1312,13 +1303,9 @@ sub _MaskPhone {
     if ( $Param{NextStateID} ) {
         $Selected{SelectedID} = $Param{NextStateID};
     }
-    elsif ( $Config->{StateDefault} ) {
-        $Selected{SelectedValue} = $Config->{StateDefault};
+    elsif ( $Config->{State} ) {
+        $Selected{SelectedValue} = $Config->{State};
     }
-    else {
-        $Selected{SelectedValue} = $Param{State};
-    }
-
     $Param{NextStatesStrg} = $LayoutObject->BuildSelection(
         Data         => $Param{NextStates},
         Name         => 'NextStateID',
@@ -1450,8 +1437,6 @@ sub _MaskPhone {
         );
     }
 
-    my $PreviewContentTypes = $ConfigObject->Get('Attachment')->{PreviewContentTypes} || {};
-
     # show attachments
     ATTACHMENT:
     for my $Attachment ( @{ $Param{Attachments} } ) {
@@ -1465,12 +1450,6 @@ sub _MaskPhone {
             next ATTACHMENT;
         }
 
-        # Add preview flag if content type is in the preview content types list.
-        # This is used to determine if the attachment can be previewed in the UI.
-        if ( $Attachment->{ContentType} && $PreviewContentTypes->{ $Attachment->{ContentType} } ) {
-            $Attachment->{Preview} = 1;
-        }
-
         push @{ $Param{AttachmentList} }, $Attachment;
     }
 
