@@ -13,7 +13,7 @@ use strict;
 use warnings;
 
 use Kernel::System::VariableCheck qw(:all);
-use Kernel::Language              qw(Translatable);
+use Kernel::Language qw(Translatable);
 
 our $ObjectManagerDisabled = 1;
 
@@ -78,11 +78,9 @@ sub Run {
         UserID   => $Self->{UserID},
     );
 
-    # redirect to ticket overview if user as no permissions for the ticket
+    # error screen, don't show ticket
     if ( !$Access ) {
-        return $LayoutObject->Redirect(
-            OP => 'Action=CustomerTicketOverview;Subaction=MyTickets;Errors=MissingTicketOrNoPermission',
-        );
+        return $LayoutObject->CustomerNoPermission( WithHeader => 'yes' );
     }
 
     # get ticket data
@@ -453,7 +451,7 @@ sub Run {
                 DynamicFieldConfig   => $DynamicFieldConfig,
                 PossibleValuesFilter => $PossibleValuesFilter,
                 ParamObject          => $ParamObject,
-                Mandatory            =>
+                Mandatory =>
                     $Config->{FollowUpDynamicField}->{ $DynamicFieldConfig->{Name} }
                     == 2,
             );
@@ -483,13 +481,13 @@ sub Run {
             $DynamicFieldHTML{ $DynamicFieldConfig->{Name} } = $BackendObject->EditFieldRender(
                 DynamicFieldConfig   => $DynamicFieldConfig,
                 PossibleValuesFilter => $PossibleValuesFilter,
-                Mandatory            =>
+                Mandatory =>
                     $Config->{FollowUpDynamicField}->{ $DynamicFieldConfig->{Name} } == 2,
-                ServerError     => $ValidationResult->{ServerError}  || '',
-                ErrorMessage    => $ValidationResult->{ErrorMessage} || '',
-                LayoutObject    => $LayoutObject,
-                ParamObject     => $ParamObject,
-                AJAXUpdate      => 1,
+                ServerError  => $ValidationResult->{ServerError}  || '',
+                ErrorMessage => $ValidationResult->{ErrorMessage} || '',
+                LayoutObject => $LayoutObject,
+                ParamObject  => $ParamObject,
+                AJAXUpdate   => 1,
                 UpdatableFields => $Self->_GetFieldsToUpdate(),
             );
         }
@@ -768,7 +766,7 @@ sub Run {
         $DynamicFieldHTML{ $DynamicFieldConfig->{Name} } = $BackendObject->EditFieldRender(
             DynamicFieldConfig   => $DynamicFieldConfig,
             PossibleValuesFilter => $PossibleValuesFilter,
-            Mandatory            =>
+            Mandatory =>
                 $Config->{FollowUpDynamicField}->{ $DynamicFieldConfig->{Name} } == 2,
             LayoutObject    => $LayoutObject,
             ParamObject     => $ParamObject,
@@ -1566,8 +1564,6 @@ sub _Mask {
             );
         }
 
-        my $PreviewContentTypes = $ConfigObject->Get('Attachment')->{PreviewContentTypes} || {};
-
         # show attachments
         # get all attachments meta data
         my @Attachments = $UploadCacheObject->FormIDGetAllFilesMeta(
@@ -1586,12 +1582,6 @@ sub _Mask {
                 next ATTACHMENT;
             }
 
-            # Add preview flag if content type is in the preview content types list.
-            # This is used to determine if the attachment can be previewed in the UI.
-            if ( $Attachment->{ContentType} && $PreviewContentTypes->{ $Attachment->{ContentType} } ) {
-                $Attachment->{Preview} = 1;
-            }
-
             push @{ $Param{AttachmentList} }, $Attachment;
         }
     }
